%define major       5
%define lname       lzma
%define libname     %mklibname %{lname} %{major}
%define libdev      %mklibname -d %{lname}

# Extra documentation is installed by xz,
# these definitions are for where they exist/go
%define xz_pkgdocdir   %{_datadir}/doc/%{name}
%define dev_pkgdocdir  %{_datadir}/doc/%{libdev}

Summary:          XZ utils
Name:             xz
Version:          5.4.3
%define subrel 1
Release:          %mkrel 1
# Scripts xz{grep,diff,less,more} and symlinks (copied from gzip) are
# GPLv2+, binaries are Public Domain (linked against LGPL getopt_long but its
# OK), documentation is Public Domain.
License:          GPLv2+ and Public Domain
Group:            Archiving/Compression
URL:              https://tukaani.org/xz/
Source0:          https://tukaani.org/xz/%{name}-%{version}.tar.xz
Source1:          xzme
Requires:         %{libname} = %{version}-%{release}
# add special tuning for text files, parameter: '--text':
Patch0:           xz-5.2.0-text-tune.patch

# CVE-2025-31115
Patch1:           77bc2d6f3b6e1506c122b03cff49c902219869e3.patch
Patch2:           bdb788137e1f1d967e0c9d885b859e5b95c1b5bf.patch
Patch3:           2ce9ab6588a94cbf04a9c174e562ea5feb00cfb3.patch
Patch4:           9a9c17712bd2a070581d9239692e527a2fe13845.patch
Patch5:           c8bb46c5a16ed02401f4a0b46c74f0f46c1b6434.patch

%rename           lzma
BuildRequires:    pkgconfig(zlib)
BuildRequires:    diffutils

%description
XZ provides very high compression ratio and fast decompression. The
core of the XZ utils is Igor Pavlov's LZMA SDK containing the actual
LZMA encoder/decoder. LZMA utils add a few scripts which provide
gzip-like command line interface and a couple of other XZ related
tools. Also provides:

- Average compression ratio 30% better than that of gzip and 15%
  better than that of bzip2.

- Decompression speed is only little slower than that of gzip, being
  two to five times faster than bzip2.

- In fast mode, compresses faster than bzip2 with a comparable
  compression ratio.

- Achieving the best compression ratios takes four to even twelve
  times longer than with bzip2. However, this doesn't affect
  decompressing speed.

- Very similar command line interface than what gzip and bzip2 have.

%package -n       %{libname}
Summary:          Libraries for decoding XZ/LZMA compression
Group:            System/Libraries
Requires(pre):    filesystem >= 2.1.9-18
Conflicts:        %{name} < %{version}-%{release}

%description -n   %{libname}
Libraries for decoding LZMA compression.

%package -n       %{libdev}
Summary:          Devel libraries & headers for liblzma
Group:            Development/C
Requires(pre):    filesystem >= 2.1.9-18
Requires:         %{libname} = %{version}
Provides:         %{lname}-devel = %{version}-%{release}
Provides:         lib%{lname}-devel = %{version}-%{release}
Provides:         xz-devel

%description -n %{libdev}
Devel libraries & headers for liblzma.

%prep
%setup -q
%autopatch -p1

%build
CFLAGS="%{optflags} -O3 -funroll-loops" \
%configure
%make_build

%install
%make_install
install -m755 %{SOURCE1} -D %{buildroot}%{_bindir}/xzme

rm -f %{buildroot}%{_libdir}/*.la
%find_lang %{name} --with-man --all-name

# Move examples to devel subpackage
mkdir -p %{buildroot}%{dev_pkgdocdir}
mv %{buildroot}%{xz_pkgdocdir}/examples* %{buildroot}%{dev_pkgdocdir}

%check
%__make check

%files -f %{name}.lang
%doc %{xz_pkgdocdir}
%{_bindir}/*
%{_mandir}/man1/*

%files -n %{libname}
%doc COPYING
%{_libdir}/liblzma.so.%{major}
%{_libdir}/liblzma.so.%{version}

%files -n %{libdev}
%doc COPYING
%doc %{dev_pkgdocdir}/examples*
%{_includedir}/%{lname}.h
%dir %{_includedir}/%{lname}
%{_includedir}/%{lname}/*.h
%{_libdir}/*.so
%{_libdir}/*.a
%{_libdir}/pkgconfig/lib%{lname}.pc


%changelog
* Fri Apr 04 2025 ns80 <ns80> 5.4.3-1.1.mga9
+ Revision: 2173378
- add upstream patches for CVE-2025-31115 (mga#34164)

* Fri May 05 2023 kekepower <kekepower> 5.4.3-1.mga9
+ Revision: 1955923
- Update to version 5.4.3

* Sun Mar 19 2023 kekepower <kekepower> 5.4.2-1.mga9
+ Revision: 1949681
- Update to version 5.4.2

* Thu Jan 12 2023 kekepower <kekepower> 5.4.1-1.mga9
+ Revision: 1932531
- Update to version 5.4.1

* Wed Dec 14 2022 kekepower <kekepower> 5.4.0-1.mga9
+ Revision: 1922014
- Update to new stable release 5.4.0

* Wed Nov 30 2022 kekepower <kekepower> 5.2.9-1.mga9
+ Revision: 1913555
- Update to version 5.2.9

* Mon Nov 14 2022 kekepower <kekepower> 5.2.8-1.mga9
+ Revision: 1907168
- Update to version 5.2.8

* Sat Oct 01 2022 kekepower <kekepower> 5.2.7-1.mga9
+ Revision: 1893619
- Update to version 5.2.7

* Sat Aug 13 2022 kekepower <kekepower> 5.2.6-1.mga9
+ Revision: 1877309
- Update to version 5.2.6

* Wed Apr 20 2022 ns80 <ns80> 5.2.5-5.mga9
+ Revision: 1851995
- add patch from Ubuntu for CVE-2022-1271 (mga#30261)

* Thu Mar 17 2022 umeabot <umeabot> 5.2.5-4.mga9
+ Revision: 1797520
- Mageia 9 Mass Rebuild
+ marja <marja>
- remove no longer needed Conflicts man-pages-de < 4.0.0-3

* Tue Feb 02 2021 pterjan <pterjan> 5.2.5-2.mga8
+ Revision: 1674563
- Add missing Conflicts

* Thu Mar 19 2020 luigiwalser <luigiwalser> 5.2.5-1.mga8
+ Revision: 1557997
- 5.2.5
- remove upstream patches

* Sun Feb 16 2020 umeabot <umeabot> 5.2.4-5.mga8
+ Revision: 1532774
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Sep 17 2019 tmb <tmb> 5.2.4-4.mga8
+ Revision: 1443121
- liblzma: Avoid memcpy(NULL, foo, 0) because it is undefined behavior
- xz: Fix an integer overflow with 32-bit off_t

* Sun Sep 23 2018 umeabot <umeabot> 5.2.4-2.mga7
+ Revision: 1302005
- Mageia 7 Mass Rebuild

* Tue May 29 2018 kekepower <kekepower> 5.2.4-1.mga7
+ Revision: 1232993
- Update to version 5.2.4

* Wed Sep 06 2017 joequant <joequant> 5.2.3-2.mga7
+ Revision: 1151683
- rebuild with gcc7

* Fri Dec 30 2016 luigiwalser <luigiwalser> 5.2.3-1.mga6
+ Revision: 1078706
- 5.2.3

* Sun Apr 03 2016 tv <tv> 5.2.2-3.mga6
+ Revision: 997766
- provides xz-devel (compatibility with FC)

* Fri Feb 12 2016 umeabot <umeabot> 5.2.2-2.mga6
+ Revision: 959352
- Mageia 6 Mass Rebuild

* Mon Oct 05 2015 shlomif <shlomif> 5.2.2-1.mga6
+ Revision: 886442
- New version 5.2.2 - patch thanks to Neal Gompa (Son_Goku).

* Fri Aug 21 2015 tmb <tmb> 5.2.1-2.mga6
+ Revision: 867621
- rebuild for new gcc

* Mon Jun 22 2015 shlomif <shlomif> 5.2.1-1.mga6
+ Revision: 839198
- New version 5.2.1

* Mon Dec 22 2014 tmb <tmb> 5.2.0-1.mga5
+ Revision: 804939
- 5.2.0 stable

* Wed Oct 15 2014 umeabot <umeabot> 5.1.4-0.beta.4.mga5
+ Revision: 740872
- Second Mageia 5 Mass Rebuild

* Thu Oct 02 2014 tmb <tmb> 5.1.4-0.beta.3.mga5
+ Revision: 734915
- make the lib conflict older xz to ensure upgrade in same transaction

* Thu Oct 02 2014 tmb <tmb> 5.1.4-0.beta.2.mga5
+ Revision: 734894
- xz must have strict deps on lzma lib as does not have stable api

* Wed Oct 01 2014 luigiwalser <luigiwalser> 5.1.4-0.beta.1.mga5
+ Revision: 733831
- update to 5.1.4beta
- rediff patch 0

* Tue Sep 16 2014 umeabot <umeabot> 5.1.3-0.alpha.3.mga5
+ Revision: 690809
- Mageia 5 Mass Rebuild

* Tue Aug 19 2014 tv <tv> 5.1.3-0.alpha.2.mga5
+ Revision: 665729
- drop dietlibc build (no more needed by stage1)

* Fri Mar 14 2014 shlomif <shlomif> 5.1.3-0.alpha.1.mga5
+ Revision: 603484
- Upgrade to 5.1.3 (MGA #13018).

* Fri Oct 18 2013 umeabot <umeabot> 5.1.2-0.alpha.4.mga4
+ Revision: 520864
- Mageia 4 Mass Rebuild

* Mon Jan 14 2013 umeabot <umeabot> 5.1.2-0.alpha.3.mga3
+ Revision: 387537
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Oct 02 2012 tv <tv> 5.1.2-0.alpha.2.mga3
+ Revision: 302007
- restore lzma provides

* Tue Oct 02 2012 tv <tv> 5.1.2-0.alpha.1.mga3
+ Revision: 302002
- new release (like FC & mdv) (multithreaded compression)
- rediff patch 0
- drop very old provides/conflicts
- fix build with dietlibc
- explain patch 0

* Sat Jul 21 2012 colin <colin> 5.0.4-2.mga3
+ Revision: 273158
- Update for usrmove

* Mon Jun 25 2012 fwang <fwang> 5.0.4-1.mga3
+ Revision: 263355
- new version 5.0.4

* Sat Apr 28 2012 colin <colin> 5.0.3-3.mga2
+ Revision: 234087
- Move liblzma to / from /usr (needed by systemctl+kmod)

* Sun Jan 15 2012 tv <tv> 5.0.3-2.mga2
+ Revision: 196475
- build with dietlibc

* Sun Jul 17 2011 fwang <fwang> 5.0.3-1.mga2
+ Revision: 125415
- new version 5.0.3

* Fri Apr 08 2011 tmb <tmb> 5.0.2-1.mga1
+ Revision: 82058
- liblzma: Fix a memory leak in stream_encoder.c (P1)
- update to 5.0.2
- update url

* Sat Jan 08 2011 blino <blino> 5.0.0-2.mga1
+ Revision: 576
- imported package xz


* Wed Dec 15 2010 Per Øyvind Karlsen <peroyvind@mandriva.org> 5.0.0-2mdv2011.0
+ Revision: 621846
- update license
- resurrect --text option patch

* Wed Nov 17 2010 Olivier Faurax <ofaurax@mandriva.org> 5.0.0-1mdv2011.0
+ Revision: 598139
- Bump version to 5.0.0

* Wed Mar 17 2010 Oden Eriksson <oeriksson@mandriva.com> 4.999.9beta-2mdv2010.1
+ Revision: 524476
- rebuilt for 2010.1

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - update summary & description due to lzma -> xz name change

* Thu Sep 03 2009 Per Øyvind Karlsen <peroyvind@mandriva.org> 4.999.9beta-1mdv2010.0
+ Revision: 428978
- update to 4.999.9beta

* Mon Mar 09 2009 Per Øyvind Karlsen <peroyvind@mandriva.org> 4.999.8beta-0.2mdv2009.1
+ Revision: 353301
- add back recompression tool (xzme, renamed from lzme, now using xz format, fixes #48231)

* Sun Jan 25 2009 Per Øyvind Karlsen <peroyvind@mandriva.org> 4.999.8beta-0.1mdv2009.1
+ Revision: 333378
- update to latest code from git (contains some fixes required by pyliblzma 0.5.0)

* Thu Jan 08 2009 Funda Wang <fwang@mandriva.org> 4.999.7-0.beta.2mdv2009.1
+ Revision: 327157
- rebuild

* Mon Jan 05 2009 Per Øyvind Karlsen <peroyvind@mandriva.org> 4.999.7-0.beta.1mdv2009.1
+ Revision: 325129
- update to 4.999.7beta

* Tue Dec 30 2008 Per Øyvind Karlsen <peroyvind@mandriva.org> 4.999.6-0.alpha.6mdv2009.1
+ Revision: 321391
- add lzme util from older lzma package (should become xzme eventually..)

* Mon Dec 29 2008 Per Øyvind Karlsen <peroyvind@mandriva.org> 4.999.6-0.alpha.5mdv2009.1
+ Revision: 321121
- rename to 'xz'
- add text tune patch (P1) which provides same --text option as we introduced for
  old tool..
- update source, new tool and format has now been renamed to 'xz'
- rename

* Mon Dec 22 2008 Oden Eriksson <oeriksson@mandriva.com> 4.999.6-0.alpha.4mdv2009.1
+ Revision: 317511
- fix major, he he he, funny!

* Sun Dec 21 2008 Oden Eriksson <oeriksson@mandriva.com> 4.999.6-0.alpha.3mdv2009.1
+ Revision: 317047
- rebuild

* Sun Oct 19 2008 Per Øyvind Karlsen <peroyvind@mandriva.org> 4.999.6-0.alpha.2mdv2009.1
+ Revision: 295258
- d'oh, bump major again due to lzmalib conflicts

* Fri Oct 17 2008 Per Øyvind Karlsen <peroyvind@mandriva.org> 4.999.6-0.alpha.1mdv2009.1
+ Revision: 294620
- * new release
  * ditch lzma-4.999.3alpha-use-lzma_alone-format-by-default.patch, this is now the
  default
  * bump major (P1)

* Fri Jul 18 2008 Per Øyvind Karlsen <peroyvind@mandriva.org> 4.999.3-0.alpha.3mdv2009.0
+ Revision: 238248
- new git snapshot
- drop P1 (fixed upstream)
- drop ldconfig scriptlets since package is new and doesn't exist in older releases

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Mon May 12 2008 Per Øyvind Karlsen <peroyvind@mandriva.org> 4.999.3-0.alpha.2mdv2009.0
+ Revision: 206503
- remove help text about options not available for LZMA_Alone (updates P0)
- handle broken pipe (P1)
- build with -O3 & -funroll-loops

* Sun May 04 2008 Per Øyvind Karlsen <peroyvind@mandriva.org> 4.999.3-0.alpha.1mdv2009.0
+ Revision: 201109
- provide liblzma-devel
- import lzma-utils


* Thu Apr 30 2008 Per Øyvind Karlsen <peroyvind@mandriva.org> 4.99.3alpha-1
- initial Mandriva release.
